

import * as vscode from "vscode";
import { homedir } from "os";
import { join } from "path";
import { existsSync } from "fs";

function getPaths(): { [key: string]: string | null } {
    const appName: string = vscode.env.appName.toLowerCase();
    let paths: { [key: string]: string | null } = {};

    let basePath: string;
    
    if (process.platform === "win32") {
        if (appName.includes("codium")) {
            basePath = join(process.env.APPDATA || "", "VSCodium", "User");
        } else if (appName.includes("oss")) {
            basePath = join(process.env.APPDATA || "", "Code - OSS", "User");
        } else {
            basePath = join(process.env.APPDATA || "", "Code", "User");
        }
    } else if (process.platform === "darwin") {
        if (appName.includes("codium")) {
            basePath = join(homedir(), "Library", "Application Support", "VSCodium", "User");
        } else if (appName.includes("oss")) {
            basePath = join(homedir(), "Library", "Application Support", "Code - OSS", "User");
        } else {
            basePath = join(homedir(), "Library", "Application Support", "Code", "User");
        }
    } else {
        if (appName.includes("codium")) {
            basePath = join(homedir(), ".config", "VSCodium", "User");
        } else if (appName.includes("oss")) {
            basePath = join(homedir(), ".config", "Code - OSS", "User");
        } else {
            basePath = join(homedir(), ".config", "Code", "User");
        }
    }

    paths["settings"] = join(basePath, "settings.json"); // file
    paths["kb_shortcuts"] = join(basePath, "keybindings.json"); // file
    paths["snippets"] = join(basePath, "snippets"); // folder
    paths["tasks"] = join(basePath, "tasks.json"); // file
    paths["ui_state"] = join(basePath, "globalStorage"); // folder
    paths["ext"] = join(basePath, "extensions"); // folder
    paths["profiles"] = join(basePath, "profiles"); // folder

    for (const key in paths) {
        if (!existsSync(paths[key] as string)) {
            paths[key] = null;
        }
    }

    return paths;
}

export function activate(context: vscode.ExtensionContext) {    
    let disposable = vscode.commands.registerCommand("forgejo-sync.getPaths", () => {
        vscode.window.showInformationMessage("Command executed");
        const settingsPath = getPaths();
		if (settingsPath) {
			console.log(settingsPath);
		}
    });

    context.subscriptions.push(disposable);
}


export function deactivate() {}
